"""Basic projectile physics"""

import entity

import pygame

class Projectile(entity.Entity):
    """A projectile, with simple physics"""
    def __init__(self, game, image, vector, despawn):
        entity.Entity.__init__(self, game, image)
        self.orig_img = self.image
        self.add_vector("projectile", vector)
        self.flying = True
        self.despawn = despawn
        
    def collidecheck(self, newpos):
        top = self.game.level.get_at(newpos.centerx, newpos.top)
        bottom = self.game.level.get_at(newpos.centerx, newpos.bottom)
        left = self.game.level.get_at(newpos.left, newpos.centery)
        right = self.game.level.get_at(newpos.right, newpos.centery)
        
        if top and top.solid == "true":
            newpos.top = top.rect.bottom
            self.flying = False
        if bottom and bottom.solid == "true":
            newpos.bottom = bottom.rect.top
            self.flying = False
        if right and right.solid == "true":
            newpos.right = right.rect.left
            self.flying = False
        if left and left.solid == "true":
            newpos.left = left.rect.right
            self.flying = False
            
        return newpos

    def update(self):
        if self.flying:
            entity.Entity.update(self)
            self.image = pygame.transform.rotate(self.orig_img, self.vector.get_angle())
            self.rect.size = self.image.get_rect().size
        else:
            if self.despawn:
                self.despawn -= 1
            else:
                self.kill()
